@@ -2,6 +2,8 @@ import csv
 from pathlib import Path
 from typing import Union, Optional, Dict
 
+from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType, AutoMapperAnyDataType
+
 
 class TranslatorProxyBase:
     def __init__(
@@ -9,9 +11,12 @@ class TranslatorProxyBase:
     ) -> None:
         self.location: Union[str, Path] = location
         self.csv_file: Union[str, Path] = csv_file
-        self.mapping_dict: Optional[Dict[str, str]] = None
+        self.mapping_dict: Optional[Dict[AutoMapperTextInputType,
+                                         AutoMapperAnyDataType]] = None
 
-    def get_mapping(self) -> Dict[str, str]:
+    def get_mapping(
+        self
+    ) -> Dict[AutoMapperTextInputType, AutoMapperAnyDataType]:
         # read csv
         # convert first two columns to dictionary
         if not self.mapping_dict:
